aboutsummaryrefslogtreecommitdiff
path: root/desiredata/src/m_pd.h
diff options
context:
space:
mode:
authorN.N. <matju@users.sourceforge.net>2009-04-24 19:30:26 +0000
committerN.N. <matju@users.sourceforge.net>2009-04-24 19:30:26 +0000
commit55aa9cac0c6d5fd457d0892e187a8403112896fc (patch)
treead3114f99f2d6442c7e1bd19bffea45451d069bd /desiredata/src/m_pd.h
parent8547f8161e9d90822a0af18843ef39d7a9c6bd76 (diff)
fixed recent blunder about A_LIST and A_ATOM
svn path=/trunk/; revision=11121
Diffstat (limited to 'desiredata/src/m_pd.h')
-rw-r--r--desiredata/src/m_pd.h13
1 files changed, 7 insertions, 6 deletions
diff --git a/desiredata/src/m_pd.h b/desiredata/src/m_pd.h
index a53ad13a..6ea90242 100644
--- a/desiredata/src/m_pd.h
+++ b/desiredata/src/m_pd.h
@@ -232,12 +232,13 @@ typedef enum {
A_SEMI, A_COMMA, /* radioactive elements of the first kind */
A_DEFFLOAT, A_DEFSYM, /* pseudo-types for optional (DEFault) arguments */
A_DOLLAR, A_DOLLSYM, /* radioactive elements of the second kind */
- A_GIMME, /* non-type: represents varargs */
- A_CANT, /* bottom type: type constraint is impossible */
- A_LIST /* t_list *, the 4th stable element (future use) */
- /* 14 = A_GRID for GridFlow */
- /* 15 = A_GRIDOUT for GridFlow */
- /* 16 could be A_ATOM, top type: type constraint doesn't constrain */
+ A_GIMME, /* non-type: represents varargs */
+ A_CANT, /* bottom type: type constraint is impossible */
+/* regular pd stops here, before #12 */
+ A_ATOM, /* top type: type constraint doesn't constrain */
+ A_LIST, /* t_list *, the 4th stable element (future use) */
+ A_GRID, /* reserved for GridFlow */
+ A_GRIDOUT, /* reserved for GridFlow */
} t_atomtype;
#define A_DEFSYMBOL A_DEFSYM /* better name for this */